package alex.carmessenger;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Created by alex on 05/03/2017.
 * Create account activity allows a user to create an account that gets stored in the database.
 * New users can then log in to the application. 
 */
public class CreateAccount extends AppCompatActivity {
    DBAdapter db;
    TextView uniqueID;
    EditText enterSurname;
    EditText enterRegNum;
    EditText enterPass;
    ImageView imageHeader;
    ImageButton copyClip;
    private String validString;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_create_account);
        Thread.setDefaultUncaughtExceptionHandler(new ErrorHandler(this));

        imageHeader = (ImageView)findViewById(R.id.createAccountCarlogoDesign);
        uniqueID = (TextView)findViewById(R.id.createAccountUniqueID);
        enterSurname = (EditText)findViewById(R.id.createAccountEnterSurname);
        enterRegNum = (EditText)findViewById(R.id.createAccountEnterRegNo);
        enterPass = (EditText)findViewById(R.id.createAccountEnterPassword);
        copyClip = (ImageButton)findViewById(R.id.createAccountCopy);

        db = new DBAdapter(this);

        Button createAccountButtonFinal = (Button)findViewById(R.id.createAccountCreateButton);
        createAccountButtonFinal.setOnClickListener(new View.OnClickListener(){
            public void onClick(View v){
                addUser();
            }
        });

        imageHeader.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
               createAccount(v);
            }
        });

        copyClip.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                copyToClipboard();
            }
        });
    }

    public void createAccount(View view){
        Intent createAccountIntent = new Intent(CreateAccount.this, HomeScreen.class);
        startActivity(createAccountIntent);
    }
    //*Adds users to the database provided as long as they can get through the validation provided. 
    // The validation just checks that none of the fields are empty, or that a registration number 
    // follows the correct regular expression. E.g. ABC11 DEF
    public void addUser() {
        db.open();
        String password = enterPass.getText().toString();
        String regNumber = enterRegNum.getText().toString();
        String surname = enterSurname.getText().toString();
        //add a database user
        if(password.isEmpty() || regNumber.isEmpty() || surname.isEmpty()){
            Toast.makeText(CreateAccount.this, "You must fill all three boxes.", Toast.LENGTH_SHORT).show();
        }
        if(patternMatched(regNumber)== false){
            Toast.makeText(this, "Invalid Reg number entered", Toast.LENGTH_SHORT).show();
        }
        else{
            uniqueID.setText(enterSurname.getText().toString() + "-" + enterRegNum.getText().toString());
            db.insertUser(uniqueID.getText().toString(),password, regNumber, surname);
            Toast.makeText(this, "Add Successful.", Toast.LENGTH_LONG).show();
        }
        db.close();
    }
//This method lets users copy their unique id from the generated text
    public String copyToClipboard(){
        ClipboardManager myClipboard = (ClipboardManager)getSystemService(CLIPBOARD_SERVICE);
        ClipData clipString = ClipData.newPlainText("Login ID",uniqueID.getText().toString());

        myClipboard.setPrimaryClip(clipString);
        return myClipboard.getPrimaryClip().toString();
    }
    //regular expression to ensure that the users only input a registration number that follows UK standard.
    public Boolean patternMatched(String string){
        Boolean validStringFound = false;
        String reg = "((?:[A-Z]{2}[0-9]{2}[A-Z]{3}$))";
        Pattern p = Pattern.compile(reg, Pattern.CASE_INSENSITIVE) ;
        Matcher m = p.matcher(string);

        if(m.find()){
            String matched1 = m.group(1);
            validStringFound = true;
            validString = matched1.toString();
        }
        if (validStringFound == true){
            return true;
        }
        return validStringFound;
    }


}
