package alex.carmessenger;
/*
Created by Alex Hutchings, for the carmessenger android application.
HomeScreen activity functionality:
Allows a user to log in with their credentials - uniqueID and a password.
Allows a user to go to the create account page if they do not have an account.
*/

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Pair;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Toast;

public class HomeScreen extends AppCompatActivity {
    DBAdapter db;
    ClipboardManager clipboardManager;
    ImageButton paste;
    EditText uniqueID;
    EditText password;
    public final static String unique_ID = "alex.carmessanger.LoginIdentifier";
    public static final String MyPREFERENCES = "MyPrefs" ;
    public static final String username = "nameKey";
    SharedPreferences sharedpreferences;
/*
Main features of this page. two textboxes that are used to handle the user input.
The two textboxes are designed to handle the user input so that they are able to log into the system.
The login button is the handler of the activity's features. When a user clicks this button,
the username and password entered into the two textboxes are cross referenced with the database
adapter class to check that they match credentials stored in the database itself.
If the credentials entered are a match, then the user is able to enter the system. If they are
incorrect an error is displayed to the user and they are not granted access to the application.
 */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_home_screen);

        sharedpreferences = getSharedPreferences(MyPREFERENCES, Context.MODE_PRIVATE);
        Thread.setDefaultUncaughtExceptionHandler(new ErrorHandler(this));
        clipboardManager = (ClipboardManager) getSystemService(CLIPBOARD_SERVICE);
        paste = (ImageButton)findViewById(R.id.homeScreenPaste);
        uniqueID = (EditText) findViewById(R.id.HomeScreenLoginIdentifier);
        password = (EditText)findViewById(R.id.homeScreenLoginPassword);

        db = new DBAdapter(this);
        db.open();

        paste.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                pasteFromBoard();
            }
        });

    }

    public void loginButton(View view){
        uniqueID = (EditText) findViewById(R.id.HomeScreenLoginIdentifier);
        password = (EditText)findViewById(R.id.homeScreenLoginPassword);
        Button loginButton = (Button)findViewById(R.id.HomeScreenLoginButton);
        loginButton.setOnClickListener(new View.OnClickListener(){
            public void onClick(View view){
                //get unique id and password from DB
                String uniqueIDEntered = uniqueID.getText().toString();
                String passEntered = password.getText().toString();

                //fetch unique id from database
                String storedUniqueID = db.getSingleEntry(uniqueIDEntered);
                String storedPass = null;
                storedPass = db.getPass(passEntered);
                //check id stored matches id entered
                if(uniqueIDEntered.equals(storedUniqueID) && passEntered.equals(storedPass)){
                    SharedPreferences.Editor editor = sharedpreferences.edit();
                    editor.putString(username, uniqueIDEntered);
                    editor.commit();
                    Toast.makeText(HomeScreen.this, "Login Successful", Toast.LENGTH_LONG).show();
                    Intent mainMenuIntent = new Intent(HomeScreen.this, MainMenu.class);
                    mainMenuIntent.putExtra(unique_ID, uniqueIDEntered);
                    startActivity(mainMenuIntent);
                    finish();
                }
                else{
                    Toast.makeText(HomeScreen.this, "Login Unsuccessful - UniqueID incorrect. ", Toast.LENGTH_LONG).show();
                }
                if(uniqueIDEntered.equals("") || uniqueIDEntered == null){
                    Toast.makeText(HomeScreen.this, "Username is empty", Toast.LENGTH_LONG).show();
                }
            }
        });

    }
    /*
    This is the create account intent method. Handles the transferring of activities when the
    user clicks on the create account button.
     */
    public void createAccountButton(View view){
        Intent createAccountIntent = new Intent(HomeScreen.this, CreateAccount.class);
        startActivity(createAccountIntent);
    }

    /*
    Paste from board is a method that allows users to paste their uniqueID from the create account
    page. It takes the item stored in the first array element of the clipboard and pastes that
    into the textbox for the uniqueID. If there is nothing stored in the clipboard then it will not
    paste anything.
     */
    public void pasteFromBoard(){
        ClipData idClip = clipboardManager.getPrimaryClip();
        ClipData.Item item = idClip.getItemAt(0);

        String text = item.getText().toString();
        uniqueID.setText(text);

    }

}

