package alex.carmessenger;

import android.*;
import android.app.Dialog;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.location.Location;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.FragmentActivity;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.GoogleMapOptions;
import com.google.android.gms.maps.MapFragment;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

import java.util.List;

public class TrafficInformation extends AppCompatActivity implements OnMapReadyCallback {
    GoogleApiClient mGoogleApiClient;
    Dialog feedbackDialog;
    Button respondToClick;
    Double mLatitude;
    Double mLongitude;
    private GoogleMap mMap;
    public DBAdapter db;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_traffic_information);
        Thread.setDefaultUncaughtExceptionHandler(new ErrorHandler(this));
        respondToClick = (Button)findViewById(R.id.customTrafficFeedbackButton);
        // Obtain the SupportMapFragment and get notified when the map is ready to be used.
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager()
                .findFragmentById(R.id.map);
        mapFragment.getMapAsync(this);

        if (mGoogleApiClient == null) {
            mGoogleApiClient = new GoogleApiClient.Builder(this)
                    .addApi(LocationServices.API)
                    .build();
        }

        db = new DBAdapter(this);
        db.open();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.menu_actions, menu);

        return super.onCreateOptionsMenu(menu);
    }
    /**
     * Manipulates the map once available.
     * This callback is triggered when the map is ready to be used.
     * This is where we can add markers or lines, add listeners or move the camera. In this case,
     * we just add a marker near Sydney, Australia.
     * If Google Play services is not installed on the device, the user will be prompted to install
     * it inside the SupportMapFragment. This method will only be triggered once the user has
     * installed Google Play services and returned to the app.
     */
    @Override
    public void onMapReady(GoogleMap googleMap) {
        mMap = googleMap;
        mMap.moveCamera(CameraUpdateFactory.newLatLngZoom(new LatLng(51.590682, -2.670786), 8.0f));
        populateAccidents();
        if (ContextCompat.checkSelfPermission(this, android.Manifest.permission.ACCESS_FINE_LOCATION) ==
                PackageManager.PERMISSION_GRANTED &&
                ContextCompat.checkSelfPermission(this, android.Manifest.permission.ACCESS_COARSE_LOCATION) ==
                        PackageManager.PERMISSION_GRANTED) {
            mMap.getUiSettings().setZoomControlsEnabled(true);
            mMap.setTrafficEnabled(true);
            mMap.setMapType(1);

        }
        mMap.setOnMarkerClickListener(new GoogleMap.OnMarkerClickListener() {
            @Override
            public boolean onMarkerClick(Marker marker) {
                try{
                    marker.showInfoWindow();
                    showDialogTraffic();
                }
                catch (IllegalArgumentException e){
                    Log.e("There was an error." , "Please try again.");
                }
                return true;
            }
        });
    }
//retrieves all the markers that are stored in the database and populates them on the map.
    public void populateAccidents(){
        List<MyMarkerObj> m = db.getMarkers();
        for(int i = 0; i < m.size(); i++) {
            String lat = m.get(i).getLat();
            String lng = m.get(i).getLng();
            LatLng latitudeAndLongitude = new LatLng(Double.valueOf(lat), Double.valueOf(lng));
            String street = m.get(i).getStreetName();
            String time = m.get(i).getAccidentTime();
            mMap.addMarker(new MarkerOptions()
                    .position(latitudeAndLongitude)
                    .title(street + " " + time)
                    .draggable(false)
            );
        }

    }

    public void showDialogTraffic(){
        feedbackDialog = new Dialog(this);
        feedbackDialog.setContentView(R.layout.custom_dialog_traffic);
        feedbackDialog.show();
    }

    public void onActionDialogTraffic(View view){
        respondToClick = (Button)feedbackDialog.findViewById(R.id.customTrafficFeedbackButton);
        final RatingBar feedbackStar = (RatingBar)feedbackDialog.findViewById(R.id.customTrafficRatingBar);
        final EditText feedbackComments = (EditText)feedbackDialog.findViewById(R.id.customTrafficFurtherComments);

            respondToClick.setOnClickListener(new View.OnClickListener(){
                @Override
                public void onClick(View v) {
                    float numStars = feedbackStar.getRating();
                    String feedback = feedbackComments.getText().toString();

                    Toast.makeText(TrafficInformation.this, numStars + " " + feedback, Toast.LENGTH_SHORT).show();
                }
            });

        }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.action_homeButton:
                Intent mainMenuIntent = new Intent(this, MainMenu.class);
                startActivity(mainMenuIntent);
                finish();
                return true;

            case R.id.action_new_message:
                Intent sendMessageIntent = new Intent(this, sendMessage.class);
                startActivity(sendMessageIntent);
                finish();
                return true;

            case R.id.action_logout:
                Intent logoutIntent = new Intent(this, HomeScreen.class);
                startActivity(logoutIntent);
                finish();
                return true;

            default:
                // If we got here, the user's action was not recognized.
                // Invoke the superclass to handle it.
                return super.onOptionsItemSelected(item);

        }
    }

    }

